#[non_exhaustive]pub enum Bk2Error {
WrongPlatform(String),
BadInteger {
key: String,
value: String,
},
MissingLogKey,
Malformed {
line: usize,
reason: &'static str,
},
Unsupported(&'static str),
}Expand description
Errors produced by .bk2 text import / export.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
WrongPlatform(String)
The header declared a platform that is not an NES family.
BadInteger
A header line declared an integer key whose value did not parse.
MissingLogKey
The input log had no LogKey: declaration line.
Malformed
A structural problem with an input-log line. line is the 1-based
input-frame line number.
Fields
Unsupported(&'static str)
A feature of the .bk2 (or of the Movie being exported) that this
module deliberately does not support.