Bk2ExportOpts

Struct Bk2ExportOpts 

pub struct Bk2ExportOpts {
    pub rerecord_count: u64,
    pub author: Option<String>,
    pub game_name: Option<String>,
    pub sha1: Option<String>,
}
Options the caller supplies on export that the Movie does not carry. Mirrors the extra header fields surfaced by Bk2Meta on import.

Fields

rerecord_count: u64

Value to emit for the rerecordCount header.

author: Option<String>

Author to emit as an Author line, if any.

game_name: Option<String>

Value to emit for the GameName header, if any.

sha1: Option<String>

Value to emit for the SHA1 header, if any.